@@ -23,8 +23,6 @@ class defaults(object):
     DEFAULT_MOBILE_FLAVOUR = u'mobile'
     FLAVOURS_TEMPLATE_PREFIX = u''
     FLAVOURS_GET_PARAMETER = u'flavour'
-    FLAVOURS_STORAGE_BACKEND = u'cookie'
-    FLAVOURS_COOKIE_KEY = u'flavour'
     FLAVOURS_SESSION_KEY = u'flavour'
     FLAVOURS_TEMPLATE_LOADERS = []
     for loader in django_settings.TEMPLATE_LOADERS:
@@ -33,5 +31,4 @@ class defaults(object):
     FLAVOURS_TEMPLATE_LOADERS = tuple(FLAVOURS_TEMPLATE_LOADERS)
     STATIC_URL_MOBILE = ''
 
-
 settings = SettingsProxy(django_settings, defaults)
